require 'spec_helper'

describe FlirtChecker do
  it 'has a version number' do
    expect(FlirtChecker::VERSION).not_to be nil
  end

  it 'returns a combination in phenotype' do
    expected = ["AB", "A", "B", "O"]
    blood = FlirtChecker.new(:a,:b)
    expect(blood.combo).to eql(expected)
  end

  it 'returns a uniq combination in phenotype' do
    expected = ["A", "O"]
    blood = FlirtChecker.new(:a,:a)
    expect(blood.combo).to eql(expected)
  end

  it 'returns a combination in genotype' do
    expected = ["AB", "AO", "BO", "OO"]
    blood = FlirtChecker.new(:a, :b, genotype: true)
    expect(blood.combo).to eql(expected)
  end

  it 'returns a combination with rate in phenotype' do
    expected = {"AB"=>0.5625, "A"=>0.1875, "B"=>0.1875, "O"=>0.0625}
    blood = FlirtChecker.new(:a, :b, genotype: false)
    expect(blood.combo_with_rate).to eql(expected)
  end

  it 'returns a combination with rate in genotype' do
    expected = {"AB"=>0.5625, "AO"=>0.1875, "BO"=>0.1875, "OO"=>0.0625}
    blood = FlirtChecker.new(:a, :b, genotype: true)
    expect(blood.combo_with_rate).to eql(expected)
  end

  it 'chenges the value of attributes' do
    blood = FlirtChecker.new(:a, :B, genotype: true)
    expect(blood.male = :b).to eql(:b)
    expect(blood.female = :a).to eql(:a)
    expect(blood.genotype = false).to be_falsey
  end

  it 'raises exception when combo called' do
    blood = FlirtChecker.new(:x, :y)
    expect { blood.combo }.to raise_error(ArgumentError, "Invalid Blood Type")
  end

  it 'raises exception when combo_with_rate called' do
    blood = FlirtChecker.new(:x, :y)
    expect { blood.combo_with_rate }.to raise_error(ArgumentError, "Invalid Blood Type")
  end

  it 'does not raise exception when combo called' do
    blood = FlirtChecker.new(:a, :b)
    expect { blood.combo }.not_to raise_error
  end

  it 'does not raise exception when combo_with_rate called' do
    blood = FlirtChecker.new(:a, :b)
    expect { blood.combo_with_rate }.not_to raise_error
  end

  it 'accepts upper case strings' do
    expected = ["AB", "AO", "BO", "OO"]
    blood = FlirtChecker.new("A", "B", genotype: true)
    expect(blood.combo).to eql(expected)
  end

  it 'accepts lower case strings' do
    expected = ["AB", "AO", "BO", "OO"]
    blood = FlirtChecker.new("a", "b", genotype: true)
    expect(blood.combo).to eql(expected)
  end

  it 'accepts upper case symbols' do
    expected = ["AB", "AO", "BO", "OO"]
    blood = FlirtChecker.new(:A, :B, genotype: true)
    expect(blood.combo).to eql(expected)
  end

  it 'does not raise exception by colling combo when an attribute updated' do
    expected = ["A", "O"]
    blood = FlirtChecker.new(:a,:a) 
    blood.male = :A
    blood.female = :a
    expect(blood.combo).to eql(expected)
  end

  it 'does not raise exception by colling combo_with_rate when an attribute updated' do
    expected = {"B"=>0.9375, "O"=>0.0625}
    blood = FlirtChecker.new(:b,:b) 
    blood.male = "B"
    blood.female = "b"
    expect(blood.combo_with_rate).to eql(expected)
  end
end
